App

Struct App 

pub struct App { /* private fields */ }
The main application builder for Celerix.

Provides a minimal API to register HTTP routes (via axum), queue consumers, and scheduled tasks — all targeting Cloudflare Workers.

Implementations

Source

impl App

pub fn new() -> App

Create a new, empty application.

pub fn get<H, T>(&mut self, path: &str, handler: H) -> &mut App
where H: Handler<T, ()> + Clone + Send + 'static, T: 'static,

Register a GET route.

pub fn post<H, T>(&mut self, path: &str, handler: H) -> &mut App
where H: Handler<T, ()> + Clone + Send + 'static, T: 'static,

Register a POST route.

pub fn put<H, T>(&mut self, path: &str, handler: H) -> &mut App
where H: Handler<T, ()> + Clone + Send + 'static, T: 'static,

Register a PUT route.

pub fn delete<H, T>(&mut self, path: &str, handler: H) -> &mut App
where H: Handler<T, ()> + Clone + Send + 'static, T: 'static,

Register a DELETE route.

pub fn patch<H, T>(&mut self, path: &str, handler: H) -> &mut App
where H: Handler<T, ()> + Clone + Send + 'static, T: 'static,

Register a PATCH route.

pub fn router(&mut self, router: Router) -> &mut App

Merge a full axum Router (for advanced use-cases / nesting).

pub fn nest(&mut self, path: &str, router: Router) -> &mut App

Nest a router under a prefix path.

pub fn queue<H>(&mut self, queue_name: &str, handler: H) -> &mut App
where H: QueueHandler,

Register a raw queue consumer for the given queue name.

pub fn schedule<F, Fut>(&mut self, handler: F) -> ScheduleBuilder<'_>
where F: Fn(Ctx) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), Error>> + 'static,

Register a scheduled task. Returns a builder to set the interval.

app.schedule(|| async {
    worker::console_log!("runs every 5s");
    Ok(())
}).every_five_seconds();

app.schedule(|| async {
    worker::console_log!("custom cron");
    Ok(())
}).cron("*/5 * * * *");

Register a scheduled task. Returns a builder to set the interval.

The closure receives a Ctx with access to queue() and storage().

app.schedule(|ctx| async move {
    let count = ctx.storage().get("counter").await?.unwrap_or_default();
    info!("counter = {count}");
    Ok(())
}).every_minute();
pub fn into_router(self) -> Router

Consume the app and return the built axum Router.

pub fn queue_handlers(&self) -> &HashMap<String, Box<dyn QueueHandler>>

Get a reference to queue handlers.

pub fn take_scheduled_tasks(&mut self) -> Vec<ScheduledTask>

Take the scheduled tasks.