pub struct Storage { /* private fields */ }Expand description
A celerix Storage handle backed by Cloudflare Workers KV.
Injected automatically as an axum Extension<Storage> by #[celerix::main].
The binding is auto-resolved to {PROJECT_NAME}_STORAGE.
KV is initialized lazily on first use, so projects that don’t use storage won’t error even without a KV binding configured.
Implementations
Sourceimpl Storage
impl Storage
Sourcepub fn get(
&self,
key: &str,
) -> SendFuture<impl Future<Output = Result<Option<String>, Error>>> ⓘ
pub fn get( &self, key: &str, ) -> SendFuture<impl Future<Output = Result<Option<String>, Error>>> ⓘ
Get a string value by key.
Sourcepub fn put(
&self,
key: &str,
value: &str,
) -> SendFuture<impl Future<Output = Result<(), Error>>> ⓘ
pub fn put( &self, key: &str, value: &str, ) -> SendFuture<impl Future<Output = Result<(), Error>>> ⓘ
Put a string value.
Sourcepub fn delete(
&self,
key: &str,
) -> SendFuture<impl Future<Output = Result<(), Error>>> ⓘ
pub fn delete( &self, key: &str, ) -> SendFuture<impl Future<Output = Result<(), Error>>> ⓘ
Delete a key.
Sourcepub fn get_item<T>(
&self,
key: &str,
) -> SendFuture<impl Future<Output = Result<Option<T>, Error>>> ⓘwhere
T: DeserializeOwned + 'static,
pub fn get_item<T>(
&self,
key: &str,
) -> SendFuture<impl Future<Output = Result<Option<T>, Error>>> ⓘwhere
T: DeserializeOwned + 'static,
Get a JSON-deserialized value by key.
ⓘ
let user: Option<User> = storage.get_item::<User>("user:123").await?;Trait Implementations